@@ -180,6 +180,10 @@ class IntegrableViewer(QOpenGLWidget):
         self.setup_model_matrix(self.model_matrix, self.rotation_angle, self.render_rotation_center)
         self.setup_view_matrix(self.view_matrix, self.render_camera_position)
 
+        # Project (Perspective/Orthographic)
+        self.proj_matrix.setToIdentity()
+        self.resizeGL(self.width(), self.height())
+
         # Propagate common uniform values (programs lacking the uniform will ignore the command)
         for collection in [self.pre_collection, self.drawable_collection, self.post_collection]:
             # MVP matrices
@@ -206,13 +210,13 @@ class IntegrableViewer(QOpenGLWidget):
         self.fps_counter.tick()
 
     def resizeGL(self, w: float, h: float) -> None:
-        self.proj_matrix.setToIdentity()
+        aspect = w / h
 
         if self.current_projection == 'Perspective':
-            self.proj_matrix.perspective(self.fov, self.aspect, 1.0, 100000.0)
+            self.proj_matrix.perspective(self.fov, aspect, 1.0, 100000.0)
         else:  # if self.current_projection == 'Orthographic':
             z = self.off_center[2] * 0.65
-            self.proj_matrix.ortho(-z, z, -z / self.aspect, z / self.aspect, 0.0, 100000.0)
+            self.proj_matrix.ortho(-z, z, -z / self.aspect, z / aspect, 0.0, 100000.0)
 
     @staticmethod
     def setup_model_matrix(matrix: QMatrix4x4, rotation: np.ndarray, translation: np.ndarray) -> None:
@@ -322,6 +326,21 @@ class IntegrableViewer(QOpenGLWidget):
     def render_rotation_center(self) -> np.ndarray:
         return self.rotation_center + self.rendering_offset
 
+    """
+    Matrices
+    """
+    @property
+    def model_matrix_math(self) -> QMatrix4x4:
+        matrix = QMatrix4x4()
+        self.setup_model_matrix(matrix, self.rotation_angle, self.rotation_center)
+        return matrix
+
+    @property
+    def view_matrix_math(self) -> QMatrix4x4:
+        matrix = QMatrix4x4()
+        self.setup_view_matrix(matrix, self.camera_position)
+        return matrix
+
     """
     API for partial camera movements/rotations
     """
@@ -720,7 +739,9 @@ class IntegrableViewer(QOpenGLWidget):
         vector = [ray_eye.x(), ray_eye.y(), ray_eye.z(), ray_eye.w()]
         temp_matrix = QMatrix4x4(*[e for e in vector for _ in range(4)])
 
-        ray_world = ((self.view_matrix * self.model_matrix).inverted()[0] * temp_matrix).column(0).toVector3D()
+        # Our self.view_matrix and self.model_matrix are altered to simplify rendering.
+        # For ray calculations, that's irrelevant, although we'll still use the correct ones for consistency.
+        ray_world = ((self.view_matrix_math * self.model_matrix_math).inverted()[0] * temp_matrix).column(0).toVector3D()
         ray = ray_world.normalized()
         return np.array([ray.x(), ray.y(), ray.z()])
 
@@ -736,7 +757,9 @@ class IntegrableViewer(QOpenGLWidget):
         # Perspective projection is straightforward
         def perspective_origin() -> np.ndarray:
             origin = (self.view_matrix * self.model_matrix).inverted()[0].column(3).toVector3D()
-            return np.array([origin.x(), origin.y(), origin.z()])
+
+            # Remember that we have a rendering offset now!
+            return np.array([origin.x(), origin.y(), origin.z()]) - self.rendering_offset
 
         # Orthographic projection needs a bit more of vector arithmetic.
         # A click in the center of the screen gives us the perfect ray,
